
.. note::

   This page is a reference documentation. It only explains the class
   signature, and not how to use it. Please refer to the
   :ref:`user guide <user_guide>` for the big picture.


{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :inherited-members:
   :special-members: __init__
   :exclude-members: set_output
   :member-order: alphabetical

.. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div style='clear:both'></div>
